﻿using System;
using System.Diagnostics;
using System.Linq;

namespace FormatNet.ConsoleUi
{
	public class Program
	{
		static void Main()
		{
			const string template = @"-{@NewLine}-{@NewLine}-{@NewLine}To:   {To.Name} ({To.Email})
From: {From.Name} ({From.Email}){@NewLine}

Subject: {Subject}

Body:
A new employee has been hired. Is name is {Account.FirstName} {Account.LastName}.
You should provide to him:
- A new smartphone?     {Account.NeedsSmartphone}
- A new pc?             {Account.NeedsPc}
- A new domain account? {Account.NeedsDomainAccount}
  - ...with a mailbox?  {Account.NeedsEmail}

Regards,
  {{From.Name}}
 
{@Tomorrow:dd/MM/yyyy}
{@User}
";


			var mail = new Mail
			{
				To = new Address( "Account manager", "accman@test.it" ),
				From = new Address( "CRM System", "crm@test.it" ),
				Subject = "A new account has been created!",
				Account = new Employee
				{
					FirstName = "Mario",
					LastName = "Rossi",
					NeedsDomainAccount = true,
					NeedsEmail = true,
					NeedsPc = true,
					NeedsSmartphone = false
				}
			};

			var formatter1 = new Formatter(
				new TokenizerViaRegex(),
				new TextFormatterStandard(),
				new TextAlignerViaStringFormat(),
				ConstantSet.CreateDefault()
			);

			var formatters = new[] { formatter1 };

			// rimuovo il rumore della prima formattazione
			foreach ( var f in formatters )
			{
				Console.WriteLine( f.Format( template, mail ) );
				Console.WriteLine();
			}

			// ora si benchmarca per davvero...
			for ( var k = 0; k < 5; k++ )
			{
				for ( var limit = 10; limit <= 100000; limit *= 10 )
				{
					Console.Write( "{0,-6} |", limit );

					foreach ( var formatter in formatters )
					{
						var f = formatter;
						var sw = Stopwatch.StartNew();
						Enumerable.Range( 1, limit )
							.ToList()
							.ForEach( x => f.Format( template, mail ) );
						sw.Stop();
						Console.Write( " {0,5} |", sw.ElapsedMilliseconds );
					}
					Console.WriteLine();
				}
				Console.WriteLine();
			}

			PressAnyKey();
		}

		static void PressAnyKey()
		{
			Console.WriteLine();
			Console.WriteLine( "Press any key to continue..." );
			Console.ReadKey( true );
		}
	}
}
