﻿using Microsoft.VisualStudio.TestTools.UnitTesting;

namespace FormatNet
{
	[TestClass]
	public abstract class TokenizerTest
	{
		public abstract ITokenizer CreateTokenizer();

		public object[] Objects
		{
			get { return new object[10]; }
		}

		[TestMethod]
		public void GetFirstToken_WithNull_ShouldReturnNull()
		{
			var tokenizer = CreateTokenizer();
			var token = tokenizer.GetFirstToken( null );
			Assert.IsNull( token );
		}

		[TestMethod]
		public void GetFirstToken_WithStringEmpty_ShouldReturnNull()
		{
			var tokenizer = CreateTokenizer();
			var token = tokenizer.GetFirstToken( string.Empty );
			Assert.IsNull( token );
		}

		[TestMethod]
		public void GetFirstToken_WithBlankString_ShouldReturnNull()
		{
			var tokenizer = CreateTokenizer();
			var token = tokenizer.GetFirstToken( "   " );
			Assert.IsNull( token );
		}

		[TestMethod]
		public void GetFirstToken_WithoutTokens_ShouldReturnNull()
		{
			var tokenizer = CreateTokenizer();
			var token = tokenizer.GetFirstToken( " prova testo senza token!" );
			Assert.IsNull( token );
		}

		[TestMethod]
		public void GetFirstToken_WithoutTokens_ShouldReturnNull2()
		{
			var tokenizer = CreateTokenizer();
			var token = tokenizer.GetFirstToken( " prova {{ testo senza } token!" );
			Assert.IsNull( token );
		}

		[TestMethod]
		public void GetFirstToken_WithPosition_ShouldReturnToken()
		{
			var constantSet = ConstantSet.CreateEmpty();
			var tokenizer = CreateTokenizer();
			var token = tokenizer.GetFirstToken( "{0}" );
			Assert.IsNotNull( token );
			Assert.AreEqual( "{0}", token.TokenString );
			var formatParameters = token.GetFormatParameters( Objects, constantSet );
			Assert.IsNotNull( formatParameters );
			Assert.AreEqual( 0, formatParameters.Position );
			Assert.AreEqual( 0, formatParameters.PropertyPath.Count );
			Assert.AreEqual( 0, formatParameters.Alignment );
			Assert.AreEqual( string.Empty, formatParameters.Format );
		}
	}
}